#
# spec file for package seatd
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           seatd
Version:        0.8.0
Release:        bp160.1.8
Summary:        Seat management daemon
License:        MIT
Group:          System/Base
URL:            https://git.sr.ht/~kennylevinsen/seatd
Source0:        %{name}-%{version}.tar.gz
BuildRequires:  meson >= 0.56.0
BuildRequires:  ninja
BuildRequires:  pkgconfig
BuildRequires:  scdoc
BuildRequires:  pkgconfig(systemd)
Requires:       libseat1 = %{version}
BuildRequires:  pkgconfig(libsystemd) >= 237

%description
Seat management takes care of mediating access to shared devices (graphics, input), without requiring the applications needing access to be root.

%package -n libseat1
Summary:        Seat management library
Group:          Development/Libraries/C and C++

%description -n libseat1
A seat management library allowing applications to use whatever seat management is available.
Supports: seatd, (e)logind, embedded seatd for standalone operation

%package devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       libseat1 = %{version}

%description devel
Development files for %{name}.

%prep
%autosetup -p1

%build
%meson -Dlibseat-logind=systemd

%meson_build

%install
%meson_install

%post -n libseat1 -p /sbin/ldconfig
%postun -n libseat1 -p /sbin/ldconfig

%files
%doc README*
%{_bindir}/%{name}
%{_bindir}/seatd-launch
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_mandir}/man1/seatd-launch.1%{?ext_man}

%files -n libseat1
%license LICENSE
%{_libdir}/libseat.so.*

%files devel
%{_includedir}/libseat.h
%{_libdir}/pkgconfig/libseat.pc
%{_libdir}/libseat.so

%changelog
* Wed Jul 19 2023 llyyr <llyyr.public@gmail.com>
- Update to 0.8.0
  * noop: Return seat0 as the seat name
  * noop: Additional open flags for `open(2)`
  * noop: initialize initial_setup
  * drm: Support drm-subtree drivers on FreeBSD
  * man: document SEATD_VTBOUND
  * man: add missing arg in -n syntax
* Fri Jun 23 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.7.0:
  * Support for NetBSD and wscons devices
  * Fix for a polling bug in the logind libseat backend
  * Removal of SEATD_SOCK and runtime socket path configuration
  * Removal of SEATD_LOGLEVEL, replaced by a command-line argument
* Fri Feb 25 2022 Michael Vetter <mvetter@suse.com>
- Update to 0.6.4
  * seatd-launch: Use snprintf for socket path
  * seatd-launch: Remove socket path command line arg
- This updates fixes bsc#1196493 (CVE-2022-25643)
* Sat Dec  4 2021 Franck Bui <fbui@suse.com>
- Enable logind support for Leap too
  Leap 15.3 ships systemd v246 which has the relevant API
  (sd_bus_match_signal) needed for enabling logind support. Since
  previous versions of Leap are not supported anymore, let's enable it
  unconditionally.
* Wed Oct 20 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.6.3:
  * logind: Set userdata for ping_handler
  * logind: Improve error handling in open_seat
  * examples/simpletest: check for libseat_dispatch failures
  * logind: check if session is active on startup
  * clang-format: Fix alignment
  * logind: Send ping to wake us up later
  * seatd: Implement ping request to wake up later
* Thu Sep 16 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.6.2:
  * seatd-launch: Specify exact environment to seatd
  * seatd-launch: Use absolute path for seatd
* Wed Sep 15 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.6.1:
  * seatd-launch: print unlink/kill errors
  * seatd-launch: exit with status >128 if child is signalled
  * man/seatd-launch: Make mssage about root clearer
  * seatd-launch: Use optind to find the command
  * seatd-launch: respect PATH when looking for command
  * man: Add seatd-launch(1) to SEE ALSO of seatd(1)
* Sat Sep 11 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.6.0:
  * seatd-launch: Fix chmod error goto
  * man: Add simple seatd-launch(1) page
  * seatd-launch: Set socket permissions directly
  * seat: Allow new clients when active is pending ack
  * Add .editorconfig
  * seat: Avoid holding a tty fd
  * meson.build: fix build with gcc < 7
  * libseat: Fix build of builtin backend
  * libseat: Update builtin backend root requirement documentation
  * Revert "libseat: Check euid before using builtin"
  * logind: Remove redundant null check
  * Make libseat_seat_listener const
  * seatd: Use path in chmod/chown operations
  * seatd: Improve socket permission error handling
  * seatd-launch: Command line argument support
  * seatd-launch: check for getpwuid errors
  * seatd-launch: don't use gotos in child processes
  * seatd-launch: propagate child exit status
  * seatd-launch: Add seatd launch wrapper
  * seatd: Only set UID/GID when specified
  * seatd: s6-style readiness notification support
  * seatd: We shouldn't poll if predispatch > 0
  * libseat: Rename dispatch_background in backends
  * libseat/seatd: Add dispatch_pending_and_execute
  * libseat/seatd: Return executed events
  * link with rt
  * readme: Update discuss section
  * meson: Support building builtin without seatd
  * libseat/seatd: downgrade ENOENT log to info
  * contrib/systemd: Use a different group
  * meson: make 'logind' var always available
  * Avoid a clang-format quirk
  * meson: declare libseat dependency
  * Add no-op session
  * client: enable cr_pid on FreeBSD >= 12.3
  * readme: Remove alpha label
  * contrib: Add Documentation to systemd unit
  * meson: Disable examples by default
  * Correct minor misspellings
  * meson: Minor cleanup
  * meson: Fix logind backend auto mode
* Thu Mar 25 2021 Denys Kondratenko <stdden@opensuse.org>
- enable logind for the libseat (disabled by default)
  * fixes errors during login, see:
    https://github.com/openSUSE/openSUSEway/issues/37
  * this works with libsystemd >= 237 with new API:
    sd_bus_match_signal
* Tue Mar 16 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.5.0:
  * libseat: log error when failing to open socket
  * poller: Retry poll immediately on EINTR
  * client: More robust handling of client links
  * logind: switch_session should return 0 on success
  * libseat/backend/logind: stop waiting for CanGraphical
  * client: Do not use SOL_SOCKET for LOCAL_PEERCRED
  * client: Use cr_pid if available
  * logind: Send ReleaseControl when closing seat
  * seatd: Tear down VT when disabled client closes
  * client: Remove link if seat_add_client succeeds
* Wed Nov 11 2020 Michael Vetter <mvetter@suse.com>
- Change _service file to use correct version number and not
  git hash
* Mon Nov  9 2020 Jan Engelhardt <jengelh@inai.de>
- Fix doubleshipping of documentation. Better summaries.
* Mon Nov  9 2020 Michael Vetter <mvetter@suse.com>
- Initial package of seatsd/libseat 0.4.0 for openSUSE
